.. _management_commands:

Management commands
===================

This section describes available, custom management commands included with
``richtemplates`` application.

``import_media`` command
------------------------

.. autoclass:: richtemplates.management.commands.import_media.Command
   :members:

..
   The ``richtemplates_init`` command
   ----------------------------------
   
   .. autoclass:: richtemplates.management.commands.richtemplates_init.Command
      :members:
   
   The ``richtemplates_init_media`` command
   ----------------------------------------
   
   .. autoclass:: richtemplates.management.commands.richtemplates_init_media.Command
      :members:

